#!/bin/bash
#SBATCH -J alphafold
#SBATCH -N 1
#SBATCH -n 8
#SBATCH --ntasks-per-node=8
#SBATCH --ntasks-per-core=1
#SBATCH --qos=mesca
#SBATCH --mem=750G 

# NE RIEN CHANGER CI-DESSUS
# AJUSTEZ A VOS BESOINS LES TROIS LIGNES SUIVANTES

#SBATCH --time=2:00:00
# SBATCH --mail-user=
# SBATCH --mail-type=ALL

module purge
module load singularity/3.6.4

#######################################################################
#
# MODIFIEZ LES DEUX LIGNES CI-DESSOUS A VOTRE CONVENANCE
#
#######################################################################

INPUT=$(pwd)/..........
MES_OPTIONS=" --max_template_date=2021-11-01 --model_preset=monomer --use_gpu_relax=0 "

##################################
#
# RIEN A CHANGER A PARTIR DE POINT
#
##################################

OUTPUT=$(pwd)/${SLURM_JOB_ID}
cp $0 $OUTPUT/$(basename $0)-mesca

echo "ALPHAFOLD - PREMIERE PARTIE (mesca)"
echo "=================================="
echo "INPUT       = $INPUT"
echo "OUTPUT      = $OUTPUT"
echo "MES_OPTIONS = $MES_OPTIONS"

############################################
#
# C'EST PARTI POUR ALPHAFOLD, msa
#
############################################

export OMP_NUM_THREADS=8

AF_VERSION='2.2.0'
ALPHAFOLD_DATA_PATH="/olympeplus/gsysinst/sysdata/alphafold/"
ALPHAFOLD_TMPDIR="/tmpdir/$(whoami)/alphafoldtmp"
mkdir -p ${ALPHAFOLD_TMPDIR}/etc

# see https://github.com/google/jax/issues/5723 
singularity run \
--env LD_LIBRARY_PATH=/usr/local/cuda/compat:/usr/local/nvidia/lib:/usr/local/nvidia/lib64:/.singularity.d/libs \
--env ALPHAFOLD_TMPDIR=$ALPHAFOLD_TMPDIR \
-B ${ALPHAFOLD_DATA_PATH}:/data \
-B ${ALPHAFOLD_TMPDIR}/etc:/etc \
--pwd  /app/alphafold \
/usr/local/containers/alphafold-${AF_VERSION}.sif \
--data_dir=/data/${AF_VERSION} \
--output_dir=$OUTPUT \
--fasta_paths=$INPUT \
--uniref90_database_path=/data/${AF_VERSION}/uniref90/uniref90.fasta  \
--mgnify_database_path=/data/${AF_VERSION}/mgnify/mgy_clusters_2018_12.fa   \
--bfd_database_path=/data/${AF_VERSION}/bfd/bfd_metaclust_clu_complete_id30_c90_final_seq.sorted_opt \
--uniclust30_database_path=/data/${AF_VERSION}/uniclust30/uniclust30_2018_08/uniclust30_2018_08 \
--pdb70_database_path=/data/${AF_VERSION}/pdb70/pdb70  \
--template_mmcif_dir=/data/${AF_VERSION}/pdb_mmcif/mmcif_files  \
--obsolete_pdbs_path=/data/${AF_VERSION}/pdb_mmcif/obsolete.dat \
--only_precompute_msas=1 \
${MES_OPTIONS}

############################################
#
# PLANIFIER LE DEMARRAGE DE LA SECONDE PARTIE 
# (démarrera seulement si ce job se termine bien)
#
# NOTE - si vous faites scancel sur ce job, ou si
#        ce job se termine en erreur, la seconde partie 
#        ne pourra pas démarrer
#        squeue -u $(whoami) montrera la raison: (DependencyNeverSatisfied)
#        N'OUBLIEZ PAS LE SUPPRIMER EGALEMENT !
#
############################################

sbatch -d afterok:${SLURM_JOB_ID} script-volta.bash


